.. py:currentmodule:: NonlinearTMM

Second-order NLTMM
##################

Main class
**********

.. autoclass:: NonlinearTMM.SecondOrderNLTMM
   :members:
   :inherited-members:
   :show-inheritance:

Helper classes
**************

.. autoclass:: NonlinearTMM._WaveSweepResultSecondOrderNLTMM
   :members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: NonlinearTMM._SweepResultSecondOrderNLTMM
   :members:
   :inherited-members:
   :show-inheritance:

.. autoclass:: NonlinearTMM._SecondOrderNLIntensities
   :members:
   :inherited-members:
   :show-inheritance:
